require 'spec_helper'

module AKAPageSpecHelper
  def validPageAttributes
    {
      :name => "test_page",
      :title => "A Test Page",
      :type => "petition"
    }
  end
end

describe ActionKitApi::Page do
  include AKAPageSpecHelper

  before(:each) do
    @page = ActionKitApi::Page.new
  end

  it "should not have a type" do
    @page.type.should be_nil
  end

  it "should be valid with valid attributes" do
    @page.update(validPageAttributes)
    @page.should be_valid
  end

  it "should verify that a name is required" do
    @page.update(validPageAttributes.except(:name))
    @page.should_not be_valid
  end

  it "should verify that a title is required" do
    @page.update(validPageAttributes.except(:title))
    @page.should_not be_valid
  end

  it "should verify that a type is required" do
    @page.update(validPageAttributes.except(:type))
    @page.should_not be_valid
  end

  it "should not allow arbitrary attributes to be added" do
    @page.update({"fake_attr" => "with some data"})
    page_hash = @page.to_hash

    page_hash.should_not include("fake_attr")
  end

  it "should return it's attributes as a hash" do
    @page.update(validPageAttributes)
    page_hash = @page.to_hash

    page_hash.should eql(validPageAttributes)
  end

end
