require 'spec_helper'

module AKAUserSpecHelper
  def validUserAttributes
    {
      :email => "tuser@example.org",
      :first_name => "Test",
      :last_name => "User",
      :zip => "00001"
    }
  end
end

describe ActionKitApi::User do
  include AKAUserSpecHelper

  before(:each) do
    @user = ActionKitApi::User.new
  end

  it "should be valid with valid attributes" do
    @user.update(validUserAttributes)
    @user.should be_valid
  end

  it "should verify that an email is required" do
    @user.update(validUserAttributes.except(:email))
    @user.should_not be_valid
  end

  it "should verify that a zip is required" do
    @user.update(validUserAttributes.except(:zip))
    @user.should_not be_valid
  end

  it "should verify that first_name is required" do
    @user.update(validUserAttributes.except(:first_name))
    @user.should_not be_valid
  end

  it "should verify that last_name is required" do
    @user.update(validUserAttributes.except(:last_name))
    @user.should_not be_valid
  end

  it "should not allow arbitrary attributes to be added" do
    @user.update({"fake_attr" => "with some data"})
    user_hash = @user.to_hash

    user_hash.should_not include("fake_attr")
  end

  it "should return it's attributes as a hash" do
    @user.update(validUserAttributes)
    user_hash = @user.to_hash

    user_hash.should eql(validUserAttributes)
  end

  it "should not try to save subscription_status" do
    pending
  end

end
